@@ -1,13 +1,11 @@
 #!/usr/bin/python3
 # This file is part of Epoptes, https://epoptes.org
-# Copyright 2010-2020 the Epoptes team, see AUTHORS.
+# Copyright 2010-2022 the Epoptes team, see AUTHORS.
 # SPDX-License-Identifier: GPL-3.0-or-later
 """
 Epoptes GUI class.
 """
 from distutils.version import LooseVersion
-import getpass
-import locale
 import os
 import pipes
 import random
@@ -34,6 +32,7 @@ LOG = logger.Logger(__file__)
 
 class EpoptesGui(object):
     """Epoptes GUI class."""
+
     def __init__(self):
         # Initialization of general-purpose variables
         self.about = None
@@ -263,25 +262,32 @@ class EpoptesGui(object):
         # Open vncviewer in listen mode
         if self.vncviewer is None or self.vncviewer.poll() is not None:
             self.vncviewer_port = self.find_unused_port()
-            # If the user installed ssvnc, prefer it over xvnc4viewer
-            if os.path.isfile('/usr/bin/ssvncviewer'):
-                self.vncviewer = subprocess.Popen(
-                    ['ssvncviewer', '-multilisten',
-                     str(self.vncviewer_port-5500)])
-            elif os.path.isfile('/usr/bin/xtigervncviewer'):
-                self.vncviewer = subprocess.Popen(
-                    ['xtigervncviewer', '-listen', str(self.vncviewer_port)])
-            elif os.path.isfile('/usr/bin/xvnc4viewer'):
-                self.vncviewer = subprocess.Popen(
-                    ['xvnc4viewer', '-listen', str(self.vncviewer_port)])
-            # Support tigervnc on rpm distributions (LP: #1501747)
-            elif os.path.isfile('/usr/share/locale/de/LC_MESSAGES/tigervnc.mo'):
-                self.vncviewer = subprocess.Popen(
-                    ['vncviewer', '-listen', str(self.vncviewer_port)])
-            # The rest of the viewers, like tightvnc
+            if os.path.isfile('/usr/share/applications/realvnc-vncviewer.desktop'):
+                viewer = 'realvnc-vnc-viewer'
+            elif os.path.isfile('/usr/bin/ssvncviewer'):
+                viewer = 'ssvncviewer'
             else:
-                self.vncviewer = subprocess.Popen(
-                    ['vncviewer', '-listen', str(self.vncviewer_port-5500)])
+                viewer = os.path.realpath('/usr/bin/vncviewer')
+                viewer = os.path.basename(viewer)
+            if viewer == 'realvnc-vnc-viewer':
+                scmd = ['vncviewer', '-uselocalcursor=0', '-scaling=aspectfit',
+                       '-securitynotificationtimeout=0', '-warnunencrypted=0',
+                       '-enabletoolbar=0', '-listen', str(self.vncviewer_port)]
+            elif viewer == 'ssvncviewer':
+                scmd = ['ssvncviewer', '-scale', 'auto', '-multilisten',
+                       str(self.vncviewer_port-5500)]
+            elif viewer == 'xtigervncviewer':
+                scmd = ['xtigervncviewer', '-listen', str(self.vncviewer_port)]
+            elif viewer == 'xtightvncviewer':
+                scmd = ['xtightvncviewer', '-listen',
+                       str(self.vncviewer_port-5500)]
+            elif viewer == 'xvnc4viewer':
+                scmd = ['xvnc4viewer',  '-uselocalcursor=0', '-listen',
+                       str(self.vncviewer_port)]
+            else:
+                # A generic vncviewer, e.g. tigervnc on Arch/Fedora/SUSE
+                scmd = ['vncviewer', '-listen', str(self.vncviewer_port)]
+            self.vncviewer = subprocess.Popen(scmd)
 
         # And, tell the clients to connect to the server
         self.exec_on_selected_clients([cmd, self.vncviewer_port] + list(args))
@@ -310,9 +316,10 @@ class EpoptesGui(object):
             self.vncserver_port = self.find_unused_port()
             self.vncserver_pwd = ''.join('\\%o' % c for c in pwd)
             self.vncserver = subprocess.Popen(
-                ['x11vnc', '-noshm', '-nopw', '-quiet', '-viewonly', '-shared',
-                 '-forever', '-nolookup', '-24to32', '-threads', '-rfbport',
-                 str(self.vncserver_port), '-rfbauth', pwdfile])
+                ['x11vnc', '-24to32', '-clip', 'xinerama0', '-forever',
+                '-nolookup', '-nopw', '-noshm', '-quiet', '-rfbauth', pwdfile,
+                '-rfbport', str(self.vncserver_port), '-shared', '-threads',
+                '-viewonly'])
         # Running `xdg-screensaver reset` as root doesn't reset the D.E.
         # screensaver, so send the reset command to both epoptes processes
         self.exec_on_selected_clients(
@@ -460,11 +467,11 @@ class EpoptesGui(object):
 
     def on_imi_help_report_bug_activate(self, _widget):
         """Handle imi_help_report_bug.activate event."""
-        self.open_url("https://bugs.launchpad.net/epoptes")
+        self.open_url("https://github.com/epoptes/epoptes/issues")
 
     def on_imi_help_ask_question_activate(self, _widget):
         """Handle imi_help_ask_question.activate event."""
-        self.open_url("https://answers.launchpad.net/epoptes")
+        self.open_url("https://github.com/epoptes/epoptes/discussions")
 
     def on_imi_help_translate_application_activate(self, _widget):
         """Handle imi_help_translate_application.activate event."""
@@ -472,11 +479,7 @@ class EpoptesGui(object):
 
     def on_imi_help_live_chat_irc_activate(self, _widget):
         """Handle imi_help_live_chat_irc.activate event."""
-        host = socket.gethostname()
-        user = getpass.getuser()
-        lang = locale.getlocale()[0]
-        self.open_url("http://ts.sch.gr/repo/irc?user=%s&host=%s&lang=%s" %
-                      (user, host, lang))
+        self.open_url("https://ltsp.org/advanced/chat-room")
 
     @staticmethod
     def on_imi_help_remote_support_activate(_widget):
@@ -979,7 +982,7 @@ class EpoptesGui(object):
                 # So if the client is too stressed and needs e.g. 7 secs to
                 # send a thumbshot, we'll ask for one every 12 secs.
                 GLib.timeout_add(int(config.system['THUMBSHOT_MS']),
-                    self.ask_thumbshot, handle)
+                                 self.ask_thumbshot, handle)
                 LOG.d("I got a thumbshot from %s." % handle)
                 if not reply:
                     return
